var canvas = document.getElementById("renderCanvas");
var engine = new BABYLON.Engine(canvas, true);
var scene = null;
var ac1 = null;
var ac2 = null;

var projectSettings = {
    envHdr: "ballroom_1k.env",
    meshes: ["numbers.glb"],
};


/**
 * Load env scene and populate with default meshes.
 */
initScene = (filename, hdr) => {
    
    BABYLON.SceneLoader.Load("assets/", filename, engine, function (newScene) {
        var reflectionTexture = new BABYLON.CubeTexture("assets/" + hdr, newScene);
        newScene.environmentTexture = reflectionTexture;
        newScene.environmentIntensity = 2;
        newScene.clearColor = new BABYLON.Color4(0.7, 0.7, 0.7, 1);

        // camera created via code works
        var camera = new BABYLON.ArcRotateCamera("MainCamera", 0, 0, 11, BABYLON.Vector3.Zero(), newScene);
        camera.setPosition(new BABYLON.Vector3(10, 5, 10));
        camera.attachControl(canvas, true);

        newScene.executeWhenReady(() => {
            scene = newScene;
            populateScene(scene);
            console.log(scene.meshes);
        });
    });
};

/**
 * Add meshes to scene.
 */
populateScene = (scene) => {
    var am = new BABYLON.AssetsManager(scene);
    ac1 = new BABYLON.AssetContainer(scene);
    ac2 = new BABYLON.AssetContainer(scene);

    for (let i = 0; i < projectSettings.meshes.length; i++) {
        var meshTask = am.addMeshTask("mesh" + i.toString(), "", "assets/", projectSettings.meshes[i]);

        meshTask.onSuccess = (task) => {
            console.log("Processing task " + task.name);
            for (let i = 0; i < task.loadedMeshes.length; i++) {
                task.loadedMeshes[i].rotation = new BABYLON.Vector3(0, Math.PI, 0);
                if (task.loadedMeshes[i].name === "Suzanne") {
                    ac1.meshes.push(task.loadedMeshes[i]);
                } else if (task.loadedMeshes[i].name === "Sphere") {
                    ac2.meshes.push(task.loadedMeshes[i]);
                    ac2.removeAllFromScene();
                }
            }
        };

        meshTask.onError = (task, message, exception) => {
            console.log(message, exception);
        };
    }

    am.onProgress = (remainingCount, totalCount, lastFinishedTask) => {
        console.log("Loading the assets: " + remainingCount + " out of " + totalCount + " items remaining.");
        console.log("Last finished task: " + lastFinishedTask.name);
    };

    am.onFinish = (tasks) => {
        engine.runRenderLoop(() => {
            scene.render();
        });
    };

    am.load();
};


initScene("camera-code.babylon", projectSettings.envHdr);

window.addEventListener('resize', function() {
    engine.resize();
});
